==> qtjambi-scxml-6.2.4-sources.jar: io/qt/scxml/QScxmlInvokableServiceFactory.java <==
package io.qt.scxml;


/**
 * <p>Creates invokable service instances</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html">QScxmlInvokableServiceFactory</a></p>
 */
public abstract class QScxmlInvokableServiceFactory extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlInvokableServiceFactory.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QScxmlInvokableServiceFactory {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.scxml.QScxmlInvokableService invoke(io.qt.scxml.QScxmlStateMachine parentStateMachine){
            return invoke_native_QScxmlStateMachine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parentStateMachine));
        }
        @io.qt.QtUninvokable
        private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QScxmlInvokableServiceFactory(io.qt.scxml.QScxmlExecutableContent.InvokeInfo, java.util.Collection, java.util.Collection, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScxmlInvokableServiceFactory(io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.Integer> names, java.util.Collection<io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters) {
        this(invokeInfo, names, parameters, (io.qt.core.QObject)null);
    }
    
    public QScxmlInvokableServiceFactory(io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.Integer> names, java.util.Collection<io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, invokeInfo, names, parameters, parent);
    }
    
    private native static void initialize_native(QScxmlInvokableServiceFactory instance, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.Integer> names, java.util.Collection<io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invokeInfo-prop">QScxmlInvokableServiceFactory::invokeInfo()const</a></p>
     */
    @io.qt.QtPropertyReader(name="invokeInfo")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo(){
        return invokeInfo_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#names-prop">QScxmlInvokableServiceFactory::names()const</a></p>
     */
    @io.qt.QtPropertyReader(name="names")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QList<java.lang.Integer> names(){
        return names_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.Integer> names_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#parameters-prop">QScxmlInvokableServiceFactory::parameters()const</a></p>
     */
    @io.qt.QtPropertyReader(name="parameters")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invoke">QScxmlInvokableServiceFactory::invoke(QScxmlStateMachine*)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract io.qt.scxml.QScxmlInvokableService invoke(io.qt.scxml.QScxmlStateMachine parentStateMachine);
    
    @io.qt.QtUninvokable
    private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScxmlInvokableServiceFactory(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-scxml-6.3.4-sources.jar: io/qt/scxml/QScxmlInvokableServiceFactory.java <==
package io.qt.scxml;


/**
 * <p>Creates invokable service instances</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html">QScxmlInvokableServiceFactory</a></p>
 */
public abstract class QScxmlInvokableServiceFactory extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlInvokableServiceFactory.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QScxmlInvokableServiceFactory {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.scxml.QScxmlInvokableService invoke(io.qt.scxml.QScxmlStateMachine parentStateMachine){
            return invoke_native_QScxmlStateMachine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parentStateMachine));
        }
        @io.qt.QtUninvokable
        private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QScxmlInvokableServiceFactory(io.qt.scxml.QScxmlExecutableContent.InvokeInfo, java.util.Collection, java.util.Collection, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScxmlInvokableServiceFactory(io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.Integer> names, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters) {
        this(invokeInfo, names, parameters, (io.qt.core.QObject)null);
    }
    
    public QScxmlInvokableServiceFactory(io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.Integer> names, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, invokeInfo, names, parameters, parent);
    }
    
    private native static void initialize_native(QScxmlInvokableServiceFactory instance, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.Integer> names, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invokeInfo-prop">QScxmlInvokableServiceFactory::invokeInfo()const</a></p>
     */
    @io.qt.QtPropertyReader(name="invokeInfo")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo(){
        return invokeInfo_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#names-prop">QScxmlInvokableServiceFactory::names()const</a></p>
     */
    @io.qt.QtPropertyReader(name="names")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QList<java.lang.Integer> names(){
        return names_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.Integer> names_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#parameters-prop">QScxmlInvokableServiceFactory::parameters()const</a></p>
     */
    @io.qt.QtPropertyReader(name="parameters")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invoke">QScxmlInvokableServiceFactory::invoke(QScxmlStateMachine*)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract io.qt.scxml.QScxmlInvokableService invoke(io.qt.scxml.QScxmlStateMachine parentStateMachine);
    
    @io.qt.QtUninvokable
    private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScxmlInvokableServiceFactory(QPrivateConstructor p) { super(p); } 
    
}
